==> apache-nuttx-apps-12.6.0.tar.gz: apps/testing/testsuites/kernel/sched/cases/api_pthread_test_001.c <==
/****************************************************************************
 * apps/testing/testsuites/kernel/sched/cases/api_pthread_test_001.c
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/

#include <nuttx/config.h>
#include <stdio.h>
#include <syslog.h>
#include <sched.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/wait.h>
#include <time.h>
#include <pthread.h>
#include <semaphore.h>
#include <stdint.h>
#include <stdarg.h>
#include <stddef.h>
#include <setjmp.h>
#include <cmocka.h>
#include "SchedTest.h"

/****************************************************************************
 * Private Functions
 ****************************************************************************/

/****************************************************************************
 * Name: sched_pthread01_threadroutine
 ****************************************************************************/

static void *sched_pthread01_threadroutine(void *arg)
{
  int flag;
  flag = 1;
  *((int *)arg) = flag;
  return NULL;
}

/****************************************************************************
 * Public Functions
 ****************************************************************************/

/****************************************************************************
 * Name: test_nuttx_sched_pthread01
 ****************************************************************************/

void test_nuttx_sched_pthread01(FAR void **state)
{
  pthread_t p_t;
  int run_flag = 0;

  /* create thread */

  pthread_create(&p_t, NULL, sched_pthread01_threadroutine, &run_flag);

  /* pthread_join Wait for the thread to end */

  pthread_join(p_t, NULL);
  assert_int_equal(run_flag, 1);
}

==> apache-nuttx-apps-12.10.0.tar.gz: apps/testing/testsuites/kernel/sched/cases/api_pthread_test_001.c <==
/****************************************************************************
 * apps/testing/testsuites/kernel/sched/cases/api_pthread_test_001.c
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.  The
 * ASF licenses this file to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance with the
 * License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 ****************************************************************************/

/****************************************************************************
 * Included Files
 ****************************************************************************/
#include <nuttx/config.h>
#include <stdio.h>
#include <syslog.h>
#include <sched.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/wait.h>
#include <time.h>
#include <pthread.h>
#include <semaphore.h>
#include <stdint.h>
#include <stdarg.h>
#include <stddef.h>
#include <setjmp.h>
#include <cmocka.h>
#include "SchedTest.h"

/****************************************************************************
 * Private Functions
 ****************************************************************************/

/****************************************************************************
 * Name: schedpthread01threadroutine
 ****************************************************************************/

static void *schedpthread01threadroutine(void *arg)
{
  int flag;
  flag = 1;
  *((int *)arg) = flag;
  return NULL;
}

/****************************************************************************
 * Public Functions
 ****************************************************************************/

/****************************************************************************
 * Name: test_nuttx_sched_pthread01
 ****************************************************************************/

void test_nuttx_sched_pthread01(FAR void **state)
{
  pthread_t p_t;
  int run_flag = 0;

  /* create thread */

  pthread_create(&p_t, NULL, schedpthread01threadroutine, &run_flag);

  /* pthread_join Wait for the thread to end */

  pthread_join(p_t, NULL);
  assert_int_equal(run_flag, 1);
}
